@@ -16,5 +16,13 @@ class EType(Enum):
 
     return EType.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EType':
+    try:
+      return EType[name]
+    except KeyError:
+      return EType.SER_UNKNOWN 
+
+
 
 
