@@ -10,6 +10,8 @@ class EErrorCode(Enum):
   RESET_BUS=5
   BUFFER_OVERRUN=6
   NO_CONFIGURATION=7
+  CONFIGURATION_OUT_OF_MEMORY=128
+  ANY_ERROR=255
   SER_UNKNOWN=-1
 
   @staticmethod
@@ -21,5 +23,13 @@ class EErrorCode(Enum):
 
     return EErrorCode.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EErrorCode':
+    try:
+      return EErrorCode[name]
+    except KeyError:
+      return EErrorCode.SER_UNKNOWN 
+
+
 
 
