@@ -7,6 +7,7 @@ class EErrorCode(Enum):
   TWI_READ_FAILED=2
   TWI_WRITE_FAILED=3
   CLOCK_HALTED=4
+  ANY_ERROR=255
   SER_UNKNOWN=-1
 
   @staticmethod
@@ -18,5 +19,13 @@ class EErrorCode(Enum):
 
     return EErrorCode.SER_UNKNOWN
 
+  @staticmethod
+  def value_of(name: str) -> 'EErrorCode':
+    try:
+      return EErrorCode[name]
+    except KeyError:
+      return EErrorCode.SER_UNKNOWN 
+
+
 
 
